Module hash_set

Module hash_set 

HashSet is an asynchronous/concurrent hash set.

Structs

ConsumableEntry
ConsumableEntry is a view into an occupied entry in a HashSet when iterating over entries in it.
HashSet
Scalable asynchronous/concurrent hash set.
OccupiedEntry
OccupiedEntry is a view into an occupied entry in a HashSet.

Type Aliases

Reserve
Reserve keeps the capacity of the associated HashSet higher than a certain level.