Proximity

Enum Proximity 

pub enum Proximity<'t, K, V> {
    Exact(Iter<'t, K, V>),
    Between(Iter<'t, K, V>),
    Smaller(Iter<'t, K, V>),
    Larger(Iter<'t, K, V>),
    Empty,
}
Proximity of the Iter to the key passed to TreeIndex::locate.

Variants



Exact(Iter<'t, K, V>)

Iter that points to the exact key.

Iter::get returns the exact key.



Between(Iter<'t, K, V>)

Iter that points to the closest smaller key and the closest larger key.

Iter::get returns the closest smaller key, and Iter::get_back returns the closest larger key.



Smaller(Iter<'t, K, V>)

Iter that points to the closest smaller key.

The TreeIndex does not contain any larger keys than the specified key, and Iter::get_back returns the closest smaller key.



Larger(Iter<'t, K, V>)

Iter that points to the closest larger key.

The TreeIndex does not contain any smaller keys than the specified key, and Iter::get returns the closest larger key.



Empty

The TreeIndex is empty.