Module hash_cache

Module hash_cache 

HashCache is an asynchronous/concurrent 32-way associative cache backed by HashMap.

Structs

ConsumableEntry
ConsumableEntry is a view into an occupied entry in a HashCache when iterating over entries in it.
HashCache
Scalable asynchronous/concurrent 32-way associative cache backed by HashMap.
OccupiedEntry
OccupiedEntry is a view into an occupied cache entry in a HashCache.
VacantEntry
VacantEntry is a view into a vacant cache entry in a HashCache.

Enums

Entry
Entry represents a single cache entry in a HashCache.
ReplaceResult
ReplaceResult is the result type of the HashCache::replace_async and HashCache::replace_sync methods.

Constants

DEFAULT_MAXIMUM_CAPACITY
The default maximum capacity of a HashCache is 256.

Type Aliases

EvictedEntry
EvictedEntry is a type alias for Option<(K, V)>.