Structs
- Consumable
Entry ConsumableEntryis a view into an occupied entry in aHashCachewhen iterating over entries in it.- Hash
Cache - Scalable asynchronous/concurrent 32-way associative cache backed by
HashMap. - Occupied
Entry OccupiedEntryis a view into an occupied cache entry in aHashCache.- Vacant
Entry VacantEntryis a view into a vacant cache entry in aHashCache.
Enums
- Entry
Entryrepresents a single cache entry in aHashCache.- Replace
Result ReplaceResultis the result type of theHashCache::replace_asyncandHashCache::replace_syncmethods.
Constants
- DEFAULT_
MAXIMUM_ CAPACITY - The default maximum capacity of a
HashCacheis256.
Type Aliases
- Evicted
Entry EvictedEntryis a type alias forOption<(K, V)>.