HashSet is an asynchronous/concurrent hash set.
Structs
- Consumable
Entry ConsumableEntryis a view into an occupied entry in aHashSetwhen iterating over entries in it.- HashSet
- Scalable asynchronous/concurrent hash set.
- Occupied
Entry OccupiedEntryis a view into an occupied entry in aHashSet.